/**
 * Copyright 2018 Google Inc. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *     http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// If the loader is already loaded, just stop.
if (!self.define) {
  const singleRequire = name => {
    if (name !== 'require') {
      name = name + '.js';
    }
    let promise = Promise.resolve();
    if (!registry[name]) {
      
        promise = new Promise(async resolve => {
          if ("document" in self) {
            const script = document.createElement("script");
            script.src = name;
            document.head.appendChild(script);
            script.onload = resolve;
          } else {
            importScripts(name);
            resolve();
          }
        });
      
    }
    return promise.then(() => {
      if (!registry[name]) {
        throw new Error(`Module ${name} didn’t register its module`);
      }
      return registry[name];
    });
  };

  const require = (names, resolve) => {
    Promise.all(names.map(singleRequire))
      .then(modules => resolve(modules.length === 1 ? modules[0] : modules));
  };
  
  const registry = {
    require: Promise.resolve(require)
  };

  self.define = (moduleName, depsNames, factory) => {
    if (registry[moduleName]) {
      // Module is already loading or loaded.
      return;
    }
    registry[moduleName] = Promise.resolve().then(() => {
      let exports = {};
      const module = {
        uri: location.origin + moduleName.slice(1)
      };
      return Promise.all(
        depsNames.map(depName => {
          switch(depName) {
            case "exports":
              return exports;
            case "module":
              return module;
            default:
              return singleRequire(depName);
          }
        })
      ).then(deps => {
        const facValue = factory(...deps);
        if(!exports.default) {
          exports.default = facValue;
        }
        return exports;
      });
    });
  };
}
define("./basic-worker-94483d7c.js",['./_commonjsHelpers-9ddb1c3a'], (function (_commonjsHelpers) { 'use strict';

  /**
   * Adapted from React: https://github.com/facebook/react/blob/master/packages/shared/formatProdErrorMessage.js
   *
   * Do not require this module directly! Use normal throw error calls. These messages will be replaced with error codes
   * during build.
   * @param {number} code
   */
  function formatProdErrorMessage(code) {
    return "Minified Redux error #" + code + "; visit https://redux.js.org/Errors?code=" + code + " for the full message or " + 'use the non-minified dev environment for full errors. ';
  }

  // Inlined version of the `symbol-observable` polyfill
  var $$observable = (function () {
    return typeof Symbol === 'function' && Symbol.observable || '@@observable';
  })();

  /**
   * These are private action types reserved by Redux.
   * For any unknown actions, you must return the current state.
   * If the current state is undefined, you must return the initial state.
   * Do not reference these action types directly in your code.
   */
  var randomString = function randomString() {
    return Math.random().toString(36).substring(7).split('').join('.');
  };

  var ActionTypes = {
    INIT: "@@redux/INIT" + randomString(),
    REPLACE: "@@redux/REPLACE" + randomString(),
    PROBE_UNKNOWN_ACTION: function PROBE_UNKNOWN_ACTION() {
      return "@@redux/PROBE_UNKNOWN_ACTION" + randomString();
    }
  };

  /**
   * @param {any} obj The object to inspect.
   * @returns {boolean} True if the argument appears to be a plain object.
   */
  function isPlainObject(obj) {
    if (typeof obj !== 'object' || obj === null) return false;
    var proto = obj;

    while (Object.getPrototypeOf(proto) !== null) {
      proto = Object.getPrototypeOf(proto);
    }

    return Object.getPrototypeOf(obj) === proto;
  }

  /**
   * @deprecated
   *
   * **We recommend using the `configureStore` method
   * of the `@reduxjs/toolkit` package**, which replaces `createStore`.
   *
   * Redux Toolkit is our recommended approach for writing Redux logic today,
   * including store setup, reducers, data fetching, and more.
   *
   * **For more details, please read this Redux docs page:**
   * **https://redux.js.org/introduction/why-rtk-is-redux-today**
   *
   * `configureStore` from Redux Toolkit is an improved version of `createStore` that
   * simplifies setup and helps avoid common bugs.
   *
   * You should not be using the `redux` core package by itself today, except for learning purposes.
   * The `createStore` method from the core `redux` package will not be removed, but we encourage
   * all users to migrate to using Redux Toolkit for all Redux code.
   *
   * If you want to use `createStore` without this visual deprecation warning, use
   * the `legacy_createStore` import instead:
   *
   * `import { legacy_createStore as createStore} from 'redux'`
   *
   */

  function createStore(reducer, preloadedState, enhancer) {
    var _ref2;

    if (typeof preloadedState === 'function' && typeof enhancer === 'function' || typeof enhancer === 'function' && typeof arguments[3] === 'function') {
      throw new Error(formatProdErrorMessage(0) );
    }

    if (typeof preloadedState === 'function' && typeof enhancer === 'undefined') {
      enhancer = preloadedState;
      preloadedState = undefined;
    }

    if (typeof enhancer !== 'undefined') {
      if (typeof enhancer !== 'function') {
        throw new Error(formatProdErrorMessage(1) );
      }

      return enhancer(createStore)(reducer, preloadedState);
    }

    if (typeof reducer !== 'function') {
      throw new Error(formatProdErrorMessage(2) );
    }

    var currentReducer = reducer;
    var currentState = preloadedState;
    var currentListeners = [];
    var nextListeners = currentListeners;
    var isDispatching = false;
    /**
     * This makes a shallow copy of currentListeners so we can use
     * nextListeners as a temporary list while dispatching.
     *
     * This prevents any bugs around consumers calling
     * subscribe/unsubscribe in the middle of a dispatch.
     */

    function ensureCanMutateNextListeners() {
      if (nextListeners === currentListeners) {
        nextListeners = currentListeners.slice();
      }
    }
    /**
     * Reads the state tree managed by the store.
     *
     * @returns {any} The current state tree of your application.
     */


    function getState() {
      if (isDispatching) {
        throw new Error(formatProdErrorMessage(3) );
      }

      return currentState;
    }
    /**
     * Adds a change listener. It will be called any time an action is dispatched,
     * and some part of the state tree may potentially have changed. You may then
     * call `getState()` to read the current state tree inside the callback.
     *
     * You may call `dispatch()` from a change listener, with the following
     * caveats:
     *
     * 1. The subscriptions are snapshotted just before every `dispatch()` call.
     * If you subscribe or unsubscribe while the listeners are being invoked, this
     * will not have any effect on the `dispatch()` that is currently in progress.
     * However, the next `dispatch()` call, whether nested or not, will use a more
     * recent snapshot of the subscription list.
     *
     * 2. The listener should not expect to see all state changes, as the state
     * might have been updated multiple times during a nested `dispatch()` before
     * the listener is called. It is, however, guaranteed that all subscribers
     * registered before the `dispatch()` started will be called with the latest
     * state by the time it exits.
     *
     * @param {Function} listener A callback to be invoked on every dispatch.
     * @returns {Function} A function to remove this change listener.
     */


    function subscribe(listener) {
      if (typeof listener !== 'function') {
        throw new Error(formatProdErrorMessage(4) );
      }

      if (isDispatching) {
        throw new Error(formatProdErrorMessage(5) );
      }

      var isSubscribed = true;
      ensureCanMutateNextListeners();
      nextListeners.push(listener);
      return function unsubscribe() {
        if (!isSubscribed) {
          return;
        }

        if (isDispatching) {
          throw new Error(formatProdErrorMessage(6) );
        }

        isSubscribed = false;
        ensureCanMutateNextListeners();
        var index = nextListeners.indexOf(listener);
        nextListeners.splice(index, 1);
        currentListeners = null;
      };
    }
    /**
     * Dispatches an action. It is the only way to trigger a state change.
     *
     * The `reducer` function, used to create the store, will be called with the
     * current state tree and the given `action`. Its return value will
     * be considered the **next** state of the tree, and the change listeners
     * will be notified.
     *
     * The base implementation only supports plain object actions. If you want to
     * dispatch a Promise, an Observable, a thunk, or something else, you need to
     * wrap your store creating function into the corresponding middleware. For
     * example, see the documentation for the `redux-thunk` package. Even the
     * middleware will eventually dispatch plain object actions using this method.
     *
     * @param {Object} action A plain object representing “what changed”. It is
     * a good idea to keep actions serializable so you can record and replay user
     * sessions, or use the time travelling `redux-devtools`. An action must have
     * a `type` property which may not be `undefined`. It is a good idea to use
     * string constants for action types.
     *
     * @returns {Object} For convenience, the same action object you dispatched.
     *
     * Note that, if you use a custom middleware, it may wrap `dispatch()` to
     * return something else (for example, a Promise you can await).
     */


    function dispatch(action) {
      if (!isPlainObject(action)) {
        throw new Error(formatProdErrorMessage(7) );
      }

      if (typeof action.type === 'undefined') {
        throw new Error(formatProdErrorMessage(8) );
      }

      if (isDispatching) {
        throw new Error(formatProdErrorMessage(9) );
      }

      try {
        isDispatching = true;
        currentState = currentReducer(currentState, action);
      } finally {
        isDispatching = false;
      }

      var listeners = currentListeners = nextListeners;

      for (var i = 0; i < listeners.length; i++) {
        var listener = listeners[i];
        listener();
      }

      return action;
    }
    /**
     * Replaces the reducer currently used by the store to calculate the state.
     *
     * You might need this if your app implements code splitting and you want to
     * load some of the reducers dynamically. You might also need this if you
     * implement a hot reloading mechanism for Redux.
     *
     * @param {Function} nextReducer The reducer for the store to use instead.
     * @returns {void}
     */


    function replaceReducer(nextReducer) {
      if (typeof nextReducer !== 'function') {
        throw new Error(formatProdErrorMessage(10) );
      }

      currentReducer = nextReducer; // This action has a similiar effect to ActionTypes.INIT.
      // Any reducers that existed in both the new and old rootReducer
      // will receive the previous state. This effectively populates
      // the new state tree with any relevant data from the old one.

      dispatch({
        type: ActionTypes.REPLACE
      });
    }
    /**
     * Interoperability point for observable/reactive libraries.
     * @returns {observable} A minimal observable of state changes.
     * For more information, see the observable proposal:
     * https://github.com/tc39/proposal-observable
     */


    function observable() {
      var _ref;

      var outerSubscribe = subscribe;
      return _ref = {
        /**
         * The minimal observable subscription method.
         * @param {Object} observer Any object that can be used as an observer.
         * The observer object should have a `next` method.
         * @returns {subscription} An object with an `unsubscribe` method that can
         * be used to unsubscribe the observable from the store, and prevent further
         * emission of values from the observable.
         */
        subscribe: function subscribe(observer) {
          if (typeof observer !== 'object' || observer === null) {
            throw new Error(formatProdErrorMessage(11) );
          }

          function observeState() {
            if (observer.next) {
              observer.next(getState());
            }
          }

          observeState();
          var unsubscribe = outerSubscribe(observeState);
          return {
            unsubscribe: unsubscribe
          };
        }
      }, _ref[$$observable] = function () {
        return this;
      }, _ref;
    } // When a store is created, an "INIT" action is dispatched so that every
    // reducer returns their initial state. This effectively populates
    // the initial state tree.


    dispatch({
      type: ActionTypes.INIT
    });
    return _ref2 = {
      dispatch: dispatch,
      subscribe: subscribe,
      getState: getState,
      replaceReducer: replaceReducer
    }, _ref2[$$observable] = observable, _ref2;
  }

  var dist = {exports: {}};

  // Cache implementation based on Erik Rasmussen's `lru-memoize`:
  // https://github.com/erikras/lru-memoize
  var NOT_FOUND = 'NOT_FOUND';

  function createSingletonCache(equals) {
    var entry;
    return {
      get: function get(key) {
        if (entry && equals(entry.key, key)) {
          return entry.value;
        }

        return NOT_FOUND;
      },
      put: function put(key, value) {
        entry = {
          key: key,
          value: value
        };
      },
      getEntries: function getEntries() {
        return entry ? [entry] : [];
      },
      clear: function clear() {
        entry = undefined;
      }
    };
  }

  function createLruCache(maxSize, equals) {
    var entries = [];

    function get(key) {
      var cacheIndex = entries.findIndex(function (entry) {
        return equals(key, entry.key);
      }); // We found a cached entry

      if (cacheIndex > -1) {
        var entry = entries[cacheIndex]; // Cached entry not at top of cache, move it to the top

        if (cacheIndex > 0) {
          entries.splice(cacheIndex, 1);
          entries.unshift(entry);
        }

        return entry.value;
      } // No entry found in cache, return sentinel


      return NOT_FOUND;
    }

    function put(key, value) {
      if (get(key) === NOT_FOUND) {
        // TODO Is unshift slow?
        entries.unshift({
          key: key,
          value: value
        });

        if (entries.length > maxSize) {
          entries.pop();
        }
      }
    }

    function getEntries() {
      return entries;
    }

    function clear() {
      entries = [];
    }

    return {
      get: get,
      put: put,
      getEntries: getEntries,
      clear: clear
    };
  }

  var defaultEqualityCheck = function defaultEqualityCheck(a, b) {
    return a === b;
  };
  function createCacheKeyComparator(equalityCheck) {
    return function areArgumentsShallowlyEqual(prev, next) {
      if (prev === null || next === null || prev.length !== next.length) {
        return false;
      } // Do this in a for loop (and not a `forEach` or an `every`) so we can determine equality as fast as possible.


      var length = prev.length;

      for (var i = 0; i < length; i++) {
        if (!equalityCheck(prev[i], next[i])) {
          return false;
        }
      }

      return true;
    };
  }
  // defaultMemoize now supports a configurable cache size with LRU behavior,
  // and optional comparison of the result value with existing values
  function defaultMemoize(func, equalityCheckOrOptions) {
    var providedOptions = typeof equalityCheckOrOptions === 'object' ? equalityCheckOrOptions : {
      equalityCheck: equalityCheckOrOptions
    };
    var _providedOptions$equa = providedOptions.equalityCheck,
        equalityCheck = _providedOptions$equa === void 0 ? defaultEqualityCheck : _providedOptions$equa,
        _providedOptions$maxS = providedOptions.maxSize,
        maxSize = _providedOptions$maxS === void 0 ? 1 : _providedOptions$maxS,
        resultEqualityCheck = providedOptions.resultEqualityCheck;
    var comparator = createCacheKeyComparator(equalityCheck);
    var cache = maxSize === 1 ? createSingletonCache(comparator) : createLruCache(maxSize, comparator); // we reference arguments instead of spreading them for performance reasons

    function memoized() {
      var value = cache.get(arguments);

      if (value === NOT_FOUND) {
        // @ts-ignore
        value = func.apply(null, arguments);

        if (resultEqualityCheck) {
          var entries = cache.getEntries();
          var matchingEntry = entries.find(function (entry) {
            return resultEqualityCheck(entry.value, value);
          });

          if (matchingEntry) {
            value = matchingEntry.value;
          }
        }

        cache.put(arguments, value);
      }

      return value;
    }

    memoized.clearCache = function () {
      return cache.clear();
    };

    return memoized;
  }

  function getDependencies(funcs) {
    var dependencies = Array.isArray(funcs[0]) ? funcs[0] : funcs;

    if (!dependencies.every(function (dep) {
      return typeof dep === 'function';
    })) {
      var dependencyTypes = dependencies.map(function (dep) {
        return typeof dep === 'function' ? "function " + (dep.name || 'unnamed') + "()" : typeof dep;
      }).join(', ');
      throw new Error("createSelector expects all input-selectors to be functions, but received the following types: [" + dependencyTypes + "]");
    }

    return dependencies;
  }

  function createSelectorCreator(memoize) {
    for (var _len = arguments.length, memoizeOptionsFromArgs = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      memoizeOptionsFromArgs[_key - 1] = arguments[_key];
    }

    var createSelector = function createSelector() {
      for (var _len2 = arguments.length, funcs = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
        funcs[_key2] = arguments[_key2];
      }

      var _recomputations = 0;

      var _lastResult; // Due to the intricacies of rest params, we can't do an optional arg after `...funcs`.
      // So, start by declaring the default value here.
      // (And yes, the words 'memoize' and 'options' appear too many times in this next sequence.)


      var directlyPassedOptions = {
        memoizeOptions: undefined
      }; // Normally, the result func or "output selector" is the last arg

      var resultFunc = funcs.pop(); // If the result func is actually an _object_, assume it's our options object

      if (typeof resultFunc === 'object') {
        directlyPassedOptions = resultFunc; // and pop the real result func off

        resultFunc = funcs.pop();
      }

      if (typeof resultFunc !== 'function') {
        throw new Error("createSelector expects an output function after the inputs, but received: [" + typeof resultFunc + "]");
      } // Determine which set of options we're using. Prefer options passed directly,
      // but fall back to options given to createSelectorCreator.


      var _directlyPassedOption = directlyPassedOptions,
          _directlyPassedOption2 = _directlyPassedOption.memoizeOptions,
          memoizeOptions = _directlyPassedOption2 === void 0 ? memoizeOptionsFromArgs : _directlyPassedOption2; // Simplifying assumption: it's unlikely that the first options arg of the provided memoizer
      // is an array. In most libs I've looked at, it's an equality function or options object.
      // Based on that, if `memoizeOptions` _is_ an array, we assume it's a full
      // user-provided array of options. Otherwise, it must be just the _first_ arg, and so
      // we wrap it in an array so we can apply it.

      var finalMemoizeOptions = Array.isArray(memoizeOptions) ? memoizeOptions : [memoizeOptions];
      var dependencies = getDependencies(funcs);
      var memoizedResultFunc = memoize.apply(void 0, [function recomputationWrapper() {
        _recomputations++; // apply arguments instead of spreading for performance.

        return resultFunc.apply(null, arguments);
      }].concat(finalMemoizeOptions)); // If a selector is called with the exact same arguments we don't need to traverse our dependencies again.

      var selector = memoize(function dependenciesChecker() {
        var params = [];
        var length = dependencies.length;

        for (var i = 0; i < length; i++) {
          // apply arguments instead of spreading and mutate a local list of params for performance.
          // @ts-ignore
          params.push(dependencies[i].apply(null, arguments));
        } // apply arguments instead of spreading for performance.


        _lastResult = memoizedResultFunc.apply(null, params);
        return _lastResult;
      });
      Object.assign(selector, {
        resultFunc: resultFunc,
        memoizedResultFunc: memoizedResultFunc,
        dependencies: dependencies,
        lastResult: function lastResult() {
          return _lastResult;
        },
        recomputations: function recomputations() {
          return _recomputations;
        },
        resetRecomputations: function resetRecomputations() {
          return _recomputations = 0;
        }
      });
      return selector;
    }; // @ts-ignore


    return createSelector;
  }
  var createSelector = /* #__PURE__ */createSelectorCreator(defaultMemoize);
  // Manual definition of state and output arguments
  var createStructuredSelector = function createStructuredSelector(selectors, selectorCreator) {
    if (selectorCreator === void 0) {
      selectorCreator = createSelector;
    }

    if (typeof selectors !== 'object') {
      throw new Error('createStructuredSelector expects first argument to be an object ' + ("where each property is a selector, instead received a " + typeof selectors));
    }

    var objectKeys = Object.keys(selectors);
    var resultSelector = selectorCreator( // @ts-ignore
    objectKeys.map(function (key) {
      return selectors[key];
    }), function () {
      for (var _len3 = arguments.length, values = new Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
        values[_key3] = arguments[_key3];
      }

      return values.reduce(function (composition, value, index) {
        composition[objectKeys[index]] = value;
        return composition;
      }, {});
    });
    return resultSelector;
  };

  var es = /*#__PURE__*/Object.freeze({
    __proto__: null,
    defaultMemoize: defaultMemoize,
    defaultEqualityCheck: defaultEqualityCheck,
    createSelectorCreator: createSelectorCreator,
    createSelector: createSelector,
    createStructuredSelector: createStructuredSelector
  });

  var require$$0 = /*@__PURE__*/_commonjsHelpers.getAugmentedNamespace(es);

  (function (module, exports) {
  	(function (global, factory) {
  	  factory(exports, require$$0) ;
  	})(_commonjsHelpers.commonjsGlobal, (function (exports, reselect) {
  	  function isStringOrNumber(value) {
  	    return typeof value === 'string' || typeof value === 'number';
  	  }

  	  var FlatObjectCache = /*#__PURE__*/function () {
  	    function FlatObjectCache() {
  	      this._cache = {};
  	    }

  	    var _proto = FlatObjectCache.prototype;

  	    _proto.set = function set(key, selectorFn) {
  	      this._cache[key] = selectorFn;
  	    };

  	    _proto.get = function get(key) {
  	      return this._cache[key];
  	    };

  	    _proto.remove = function remove(key) {
  	      delete this._cache[key];
  	    };

  	    _proto.clear = function clear() {
  	      this._cache = {};
  	    };

  	    _proto.isValidCacheKey = function isValidCacheKey(cacheKey) {
  	      return isStringOrNumber(cacheKey);
  	    };

  	    return FlatObjectCache;
  	  }();

  	  var defaultCacheCreator = FlatObjectCache;

  	  var defaultCacheKeyValidator = function defaultCacheKeyValidator() {
  	    return true;
  	  };

  	  function createCachedSelector() {
  	    for (var _len = arguments.length, funcs = new Array(_len), _key = 0; _key < _len; _key++) {
  	      funcs[_key] = arguments[_key];
  	    }

  	    return function (polymorphicOptions, legacyOptions) {
  	      if (legacyOptions) {
  	        throw new Error('[re-reselect] "options" as second argument is not supported anymore. Please provide an option object as single argument.');
  	      }

  	      var options = typeof polymorphicOptions === 'function' ? {
  	        keySelector: polymorphicOptions
  	      } : Object.assign({}, polymorphicOptions); // https://github.com/reduxjs/reselect/blob/v4.0.0/src/index.js#L54

  	      var recomputations = 0;
  	      var resultFunc = funcs.pop();
  	      var dependencies = Array.isArray(funcs[0]) ? funcs[0] : [].concat(funcs);

  	      var resultFuncWithRecomputations = function resultFuncWithRecomputations() {
  	        recomputations++;
  	        return resultFunc.apply(void 0, arguments);
  	      };

  	      funcs.push(resultFuncWithRecomputations);
  	      var cache = options.cacheObject || new defaultCacheCreator();
  	      var selectorCreator = options.selectorCreator || reselect.createSelector;
  	      var isValidCacheKey = cache.isValidCacheKey || defaultCacheKeyValidator;

  	      if (options.keySelectorCreator) {
  	        options.keySelector = options.keySelectorCreator({
  	          keySelector: options.keySelector,
  	          inputSelectors: dependencies,
  	          resultFunc: resultFunc
  	        });
  	      } // Application receives this function


  	      var selector = function selector() {
  	        var cacheKey = options.keySelector.apply(options, arguments);

  	        if (isValidCacheKey(cacheKey)) {
  	          var cacheResponse = cache.get(cacheKey);

  	          if (cacheResponse === undefined) {
  	            cacheResponse = selectorCreator.apply(void 0, funcs);
  	            cache.set(cacheKey, cacheResponse);
  	          }

  	          return cacheResponse.apply(void 0, arguments);
  	        }

  	        console.warn("[re-reselect] Invalid cache key \"" + cacheKey + "\" has been returned by keySelector function.");
  	        return undefined;
  	      }; // Further selector methods


  	      selector.getMatchingSelector = function () {
  	        var cacheKey = options.keySelector.apply(options, arguments); // @NOTE It might update cache hit count in LRU-like caches

  	        return cache.get(cacheKey);
  	      };

  	      selector.removeMatchingSelector = function () {
  	        var cacheKey = options.keySelector.apply(options, arguments);
  	        cache.remove(cacheKey);
  	      };

  	      selector.clearCache = function () {
  	        cache.clear();
  	      };

  	      selector.resultFunc = resultFunc;
  	      selector.dependencies = dependencies;
  	      selector.cache = cache;

  	      selector.recomputations = function () {
  	        return recomputations;
  	      };

  	      selector.resetRecomputations = function () {
  	        return recomputations = 0;
  	      };

  	      selector.keySelector = options.keySelector;
  	      return selector;
  	    };
  	  }

  	  function createStructuredCachedSelector(selectors) {
  	    return reselect.createStructuredSelector(selectors, createCachedSelector);
  	  }

  	  function validateCacheSize(cacheSize) {
  	    if (cacheSize === undefined) {
  	      throw new Error('Missing the required property "cacheSize".');
  	    }

  	    if (!Number.isInteger(cacheSize) || cacheSize <= 0) {
  	      throw new Error('The "cacheSize" property must be a positive integer value.');
  	    }
  	  }

  	  var FifoObjectCache = /*#__PURE__*/function () {
  	    function FifoObjectCache(_temp) {
  	      var _ref = _temp === void 0 ? {} : _temp,
  	          cacheSize = _ref.cacheSize;

  	      validateCacheSize(cacheSize);
  	      this._cache = {};
  	      this._cacheOrdering = [];
  	      this._cacheSize = cacheSize;
  	    }

  	    var _proto = FifoObjectCache.prototype;

  	    _proto.set = function set(key, selectorFn) {
  	      this._cache[key] = selectorFn;

  	      this._cacheOrdering.push(key);

  	      if (this._cacheOrdering.length > this._cacheSize) {
  	        var earliest = this._cacheOrdering[0];
  	        this.remove(earliest);
  	      }
  	    };

  	    _proto.get = function get(key) {
  	      return this._cache[key];
  	    };

  	    _proto.remove = function remove(key) {
  	      var index = this._cacheOrdering.indexOf(key);

  	      if (index > -1) {
  	        this._cacheOrdering.splice(index, 1);
  	      }

  	      delete this._cache[key];
  	    };

  	    _proto.clear = function clear() {
  	      this._cache = {};
  	      this._cacheOrdering = [];
  	    };

  	    _proto.isValidCacheKey = function isValidCacheKey(cacheKey) {
  	      return isStringOrNumber(cacheKey);
  	    };

  	    return FifoObjectCache;
  	  }();

  	  var LruObjectCache = /*#__PURE__*/function () {
  	    function LruObjectCache(_temp) {
  	      var _ref = _temp === void 0 ? {} : _temp,
  	          cacheSize = _ref.cacheSize;

  	      validateCacheSize(cacheSize);
  	      this._cache = {};
  	      this._cacheOrdering = [];
  	      this._cacheSize = cacheSize;
  	    }

  	    var _proto = LruObjectCache.prototype;

  	    _proto.set = function set(key, selectorFn) {
  	      this._cache[key] = selectorFn;

  	      this._registerCacheHit(key);

  	      if (this._cacheOrdering.length > this._cacheSize) {
  	        var earliest = this._cacheOrdering[0];
  	        this.remove(earliest);
  	      }
  	    };

  	    _proto.get = function get(key) {
  	      this._registerCacheHit(key);

  	      return this._cache[key];
  	    };

  	    _proto.remove = function remove(key) {
  	      this._deleteCacheHit(key);

  	      delete this._cache[key];
  	    };

  	    _proto.clear = function clear() {
  	      this._cache = {};
  	      this._cacheOrdering = [];
  	    };

  	    _proto._registerCacheHit = function _registerCacheHit(key) {
  	      this._deleteCacheHit(key);

  	      this._cacheOrdering.push(key);
  	    };

  	    _proto._deleteCacheHit = function _deleteCacheHit(key) {
  	      var index = this._cacheOrdering.indexOf(key);

  	      if (index > -1) {
  	        this._cacheOrdering.splice(index, 1);
  	      }
  	    };

  	    _proto.isValidCacheKey = function isValidCacheKey(cacheKey) {
  	      return isStringOrNumber(cacheKey);
  	    };

  	    return LruObjectCache;
  	  }();

  	  var FlatMapCache = /*#__PURE__*/function () {
  	    function FlatMapCache() {
  	      this._cache = new Map();
  	    }

  	    var _proto = FlatMapCache.prototype;

  	    _proto.set = function set(key, selectorFn) {
  	      this._cache.set(key, selectorFn);
  	    };

  	    _proto.get = function get(key) {
  	      return this._cache.get(key);
  	    };

  	    _proto.remove = function remove(key) {
  	      this._cache["delete"](key);
  	    };

  	    _proto.clear = function clear() {
  	      this._cache.clear();
  	    };

  	    return FlatMapCache;
  	  }();

  	  var FifoMapCache = /*#__PURE__*/function () {
  	    function FifoMapCache(_temp) {
  	      var _ref = _temp === void 0 ? {} : _temp,
  	          cacheSize = _ref.cacheSize;

  	      validateCacheSize(cacheSize);
  	      this._cache = new Map();
  	      this._cacheSize = cacheSize;
  	    }

  	    var _proto = FifoMapCache.prototype;

  	    _proto.set = function set(key, selectorFn) {
  	      this._cache.set(key, selectorFn);

  	      if (this._cache.size > this._cacheSize) {
  	        var earliest = this._cache.keys().next().value;

  	        this.remove(earliest);
  	      }
  	    };

  	    _proto.get = function get(key) {
  	      return this._cache.get(key);
  	    };

  	    _proto.remove = function remove(key) {
  	      this._cache["delete"](key);
  	    };

  	    _proto.clear = function clear() {
  	      this._cache.clear();
  	    };

  	    return FifoMapCache;
  	  }();

  	  var LruMapCache = /*#__PURE__*/function () {
  	    function LruMapCache(_temp) {
  	      var _ref = _temp === void 0 ? {} : _temp,
  	          cacheSize = _ref.cacheSize;

  	      validateCacheSize(cacheSize);
  	      this._cache = new Map();
  	      this._cacheSize = cacheSize;
  	    }

  	    var _proto = LruMapCache.prototype;

  	    _proto.set = function set(key, selectorFn) {
  	      this._cache.set(key, selectorFn);

  	      if (this._cache.size > this._cacheSize) {
  	        var earliest = this._cache.keys().next().value;

  	        this.remove(earliest);
  	      }
  	    };

  	    _proto.get = function get(key) {
  	      var value = this._cache.get(key); // Register cache hit


  	      if (this._cache.has(key)) {
  	        this.remove(key);

  	        this._cache.set(key, value);
  	      }

  	      return value;
  	    };

  	    _proto.remove = function remove(key) {
  	      this._cache["delete"](key);
  	    };

  	    _proto.clear = function clear() {
  	      this._cache.clear();
  	    };

  	    return LruMapCache;
  	  }();

  	  exports.FifoMapCache = FifoMapCache;
  	  exports.FifoObjectCache = FifoObjectCache;
  	  exports.FlatMapCache = FlatMapCache;
  	  exports.FlatObjectCache = FlatObjectCache;
  	  exports.LruMapCache = LruMapCache;
  	  exports.LruObjectCache = LruObjectCache;
  	  exports.createCachedSelector = createCachedSelector;
  	  exports.createStructuredCachedSelector = createStructuredCachedSelector;
  	  exports["default"] = createCachedSelector;

  	  Object.defineProperty(exports, '__esModule', { value: true });

  	}));
  	
  } (dist, dist.exports));

  var createCachedSelector = /*@__PURE__*/_commonjsHelpers.getDefaultExportFromCjs(dist.exports);

  function cacheByValue(_, val) {
    return "" + val || "";
  }
  function one(state) {
    return state.counter;
  }
  function two(state, [hello]) {
    return `${hello} ${one(state) / 2}`;
  }
  const three = createSelector(state => state, state => {
    return state.counter * 2;
  });
  const four = createCachedSelector(state => state, (_, val) => val, state => three(state), (_, val, res) => {
    console.log(_, res, val);
    return val * 3;
  })({
    keySelector: cacheByValue,
    cacheObject: new dist.exports.LruMapCache({
      cacheSize: 5
    })
  });
  const selectors = {
    one,
    two,
    three,
    four
  };

  let init = {
    counter: 0
  };
  const reduce = _commonjsHelpers.produce((draft, action) => {
    switch (action.type) {
      case "INCREMENT":
        draft.counter++;
        break;
      case "DECREMENT":
        draft.counter--;
        break;
    }
  });
  const reducer = (state = init, action) => {
    const next = reduce(state, action);
    return next;
  };
  const store = createStore(reducer);
  const listeners = new Map();
  addEventListener("message", ({
    data
  }) => {
    switch (data.type) {
      case "dispatch":
        store.dispatch(data.action);
        break;
      case "subscribe":
        listeners.set(data.uuid, data.selector);
        runSelector(data.selector, data.uuid);
        break;
      case "unsubscribe":
        listeners.delete(data.uuid);
        break;
    }
  });
  store.subscribe(() => {
    listeners.forEach(runSelector);
  });
  function runSelector(value, key) {
    const selector = selectors[value.selector];
    const params = value.params ?? [];
    const returnValue = selector.apply(null, ...[store.getState(), params]);
    postMessage({
      uuid: key,
      value: returnValue
    });
  }

}));
//# sourceMappingURL=basic-worker-94483d7c.js.map
