/**
 * Copyright 2018 Google Inc. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *     http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// If the loader is already loaded, just stop.
if (!self.define) {
  const singleRequire = name => {
    if (name !== 'require') {
      name = name + '.js';
    }
    let promise = Promise.resolve();
    if (!registry[name]) {
      
        promise = new Promise(async resolve => {
          if ("document" in self) {
            const script = document.createElement("script");
            script.src = name;
            document.head.appendChild(script);
            script.onload = resolve;
          } else {
            importScripts(name);
            resolve();
          }
        });
      
    }
    return promise.then(() => {
      if (!registry[name]) {
        throw new Error(`Module ${name} didn’t register its module`);
      }
      return registry[name];
    });
  };

  const require = (names, resolve) => {
    Promise.all(names.map(singleRequire))
      .then(modules => resolve(modules.length === 1 ? modules[0] : modules));
  };
  
  const registry = {
    require: Promise.resolve(require)
  };

  self.define = (moduleName, depsNames, factory) => {
    if (registry[moduleName]) {
      // Module is already loading or loaded.
      return;
    }
    registry[moduleName] = Promise.resolve().then(() => {
      let exports = {};
      const module = {
        uri: location.origin + moduleName.slice(1)
      };
      return Promise.all(
        depsNames.map(depName => {
          switch(depName) {
            case "exports":
              return exports;
            case "module":
              return module;
            default:
              return singleRequire(depName);
          }
        })
      ).then(deps => {
        const facValue = factory(...deps);
        if(!exports.default) {
          exports.default = facValue;
        }
        return exports;
      });
    });
  };
}
define("./basic-worker-dc2c9760.js",['./immer.esm-873d4636'], (function (immer_esm) { 'use strict';

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, {
        value: value,
        enumerable: true,
        configurable: true,
        writable: true
      });
    } else {
      obj[key] = value;
    }

    return obj;
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);

    if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);

      if (enumerableOnly) {
        symbols = symbols.filter(function (sym) {
          return Object.getOwnPropertyDescriptor(object, sym).enumerable;
        });
      }

      keys.push.apply(keys, symbols);
    }

    return keys;
  }

  function _objectSpread2(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};

      if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }

    return target;
  }

  /**
   * Adapted from React: https://github.com/facebook/react/blob/master/packages/shared/formatProdErrorMessage.js
   *
   * Do not require this module directly! Use normal throw error calls. These messages will be replaced with error codes
   * during build.
   * @param {number} code
   */
  function formatProdErrorMessage(code) {
    return "Minified Redux error #" + code + "; visit https://redux.js.org/Errors?code=" + code + " for the full message or " + 'use the non-minified dev environment for full errors. ';
  }

  // Inlined version of the `symbol-observable` polyfill
  var $$observable = (function () {
    return typeof Symbol === 'function' && Symbol.observable || '@@observable';
  })();

  /**
   * These are private action types reserved by Redux.
   * For any unknown actions, you must return the current state.
   * If the current state is undefined, you must return the initial state.
   * Do not reference these action types directly in your code.
   */
  var randomString = function randomString() {
    return Math.random().toString(36).substring(7).split('').join('.');
  };

  var ActionTypes = {
    INIT: "@@redux/INIT" + randomString(),
    REPLACE: "@@redux/REPLACE" + randomString(),
    PROBE_UNKNOWN_ACTION: function PROBE_UNKNOWN_ACTION() {
      return "@@redux/PROBE_UNKNOWN_ACTION" + randomString();
    }
  };

  /**
   * @param {any} obj The object to inspect.
   * @returns {boolean} True if the argument appears to be a plain object.
   */
  function isPlainObject$1(obj) {
    if (typeof obj !== 'object' || obj === null) return false;
    var proto = obj;

    while (Object.getPrototypeOf(proto) !== null) {
      proto = Object.getPrototypeOf(proto);
    }

    return Object.getPrototypeOf(obj) === proto;
  }

  /**
   * @deprecated
   *
   * **We recommend using the `configureStore` method
   * of the `@reduxjs/toolkit` package**, which replaces `createStore`.
   *
   * Redux Toolkit is our recommended approach for writing Redux logic today,
   * including store setup, reducers, data fetching, and more.
   *
   * **For more details, please read this Redux docs page:**
   * **https://redux.js.org/introduction/why-rtk-is-redux-today**
   *
   * `configureStore` from Redux Toolkit is an improved version of `createStore` that
   * simplifies setup and helps avoid common bugs.
   *
   * You should not be using the `redux` core package by itself today, except for learning purposes.
   * The `createStore` method from the core `redux` package will not be removed, but we encourage
   * all users to migrate to using Redux Toolkit for all Redux code.
   *
   * If you want to use `createStore` without this visual deprecation warning, use
   * the `legacy_createStore` import instead:
   *
   * `import { legacy_createStore as createStore} from 'redux'`
   *
   */

  function createStore(reducer, preloadedState, enhancer) {
    var _ref2;

    if (typeof preloadedState === 'function' && typeof enhancer === 'function' || typeof enhancer === 'function' && typeof arguments[3] === 'function') {
      throw new Error(formatProdErrorMessage(0) );
    }

    if (typeof preloadedState === 'function' && typeof enhancer === 'undefined') {
      enhancer = preloadedState;
      preloadedState = undefined;
    }

    if (typeof enhancer !== 'undefined') {
      if (typeof enhancer !== 'function') {
        throw new Error(formatProdErrorMessage(1) );
      }

      return enhancer(createStore)(reducer, preloadedState);
    }

    if (typeof reducer !== 'function') {
      throw new Error(formatProdErrorMessage(2) );
    }

    var currentReducer = reducer;
    var currentState = preloadedState;
    var currentListeners = [];
    var nextListeners = currentListeners;
    var isDispatching = false;
    /**
     * This makes a shallow copy of currentListeners so we can use
     * nextListeners as a temporary list while dispatching.
     *
     * This prevents any bugs around consumers calling
     * subscribe/unsubscribe in the middle of a dispatch.
     */

    function ensureCanMutateNextListeners() {
      if (nextListeners === currentListeners) {
        nextListeners = currentListeners.slice();
      }
    }
    /**
     * Reads the state tree managed by the store.
     *
     * @returns {any} The current state tree of your application.
     */


    function getState() {
      if (isDispatching) {
        throw new Error(formatProdErrorMessage(3) );
      }

      return currentState;
    }
    /**
     * Adds a change listener. It will be called any time an action is dispatched,
     * and some part of the state tree may potentially have changed. You may then
     * call `getState()` to read the current state tree inside the callback.
     *
     * You may call `dispatch()` from a change listener, with the following
     * caveats:
     *
     * 1. The subscriptions are snapshotted just before every `dispatch()` call.
     * If you subscribe or unsubscribe while the listeners are being invoked, this
     * will not have any effect on the `dispatch()` that is currently in progress.
     * However, the next `dispatch()` call, whether nested or not, will use a more
     * recent snapshot of the subscription list.
     *
     * 2. The listener should not expect to see all state changes, as the state
     * might have been updated multiple times during a nested `dispatch()` before
     * the listener is called. It is, however, guaranteed that all subscribers
     * registered before the `dispatch()` started will be called with the latest
     * state by the time it exits.
     *
     * @param {Function} listener A callback to be invoked on every dispatch.
     * @returns {Function} A function to remove this change listener.
     */


    function subscribe(listener) {
      if (typeof listener !== 'function') {
        throw new Error(formatProdErrorMessage(4) );
      }

      if (isDispatching) {
        throw new Error(formatProdErrorMessage(5) );
      }

      var isSubscribed = true;
      ensureCanMutateNextListeners();
      nextListeners.push(listener);
      return function unsubscribe() {
        if (!isSubscribed) {
          return;
        }

        if (isDispatching) {
          throw new Error(formatProdErrorMessage(6) );
        }

        isSubscribed = false;
        ensureCanMutateNextListeners();
        var index = nextListeners.indexOf(listener);
        nextListeners.splice(index, 1);
        currentListeners = null;
      };
    }
    /**
     * Dispatches an action. It is the only way to trigger a state change.
     *
     * The `reducer` function, used to create the store, will be called with the
     * current state tree and the given `action`. Its return value will
     * be considered the **next** state of the tree, and the change listeners
     * will be notified.
     *
     * The base implementation only supports plain object actions. If you want to
     * dispatch a Promise, an Observable, a thunk, or something else, you need to
     * wrap your store creating function into the corresponding middleware. For
     * example, see the documentation for the `redux-thunk` package. Even the
     * middleware will eventually dispatch plain object actions using this method.
     *
     * @param {Object} action A plain object representing “what changed”. It is
     * a good idea to keep actions serializable so you can record and replay user
     * sessions, or use the time travelling `redux-devtools`. An action must have
     * a `type` property which may not be `undefined`. It is a good idea to use
     * string constants for action types.
     *
     * @returns {Object} For convenience, the same action object you dispatched.
     *
     * Note that, if you use a custom middleware, it may wrap `dispatch()` to
     * return something else (for example, a Promise you can await).
     */


    function dispatch(action) {
      if (!isPlainObject$1(action)) {
        throw new Error(formatProdErrorMessage(7) );
      }

      if (typeof action.type === 'undefined') {
        throw new Error(formatProdErrorMessage(8) );
      }

      if (isDispatching) {
        throw new Error(formatProdErrorMessage(9) );
      }

      try {
        isDispatching = true;
        currentState = currentReducer(currentState, action);
      } finally {
        isDispatching = false;
      }

      var listeners = currentListeners = nextListeners;

      for (var i = 0; i < listeners.length; i++) {
        var listener = listeners[i];
        listener();
      }

      return action;
    }
    /**
     * Replaces the reducer currently used by the store to calculate the state.
     *
     * You might need this if your app implements code splitting and you want to
     * load some of the reducers dynamically. You might also need this if you
     * implement a hot reloading mechanism for Redux.
     *
     * @param {Function} nextReducer The reducer for the store to use instead.
     * @returns {void}
     */


    function replaceReducer(nextReducer) {
      if (typeof nextReducer !== 'function') {
        throw new Error(formatProdErrorMessage(10) );
      }

      currentReducer = nextReducer; // This action has a similiar effect to ActionTypes.INIT.
      // Any reducers that existed in both the new and old rootReducer
      // will receive the previous state. This effectively populates
      // the new state tree with any relevant data from the old one.

      dispatch({
        type: ActionTypes.REPLACE
      });
    }
    /**
     * Interoperability point for observable/reactive libraries.
     * @returns {observable} A minimal observable of state changes.
     * For more information, see the observable proposal:
     * https://github.com/tc39/proposal-observable
     */


    function observable() {
      var _ref;

      var outerSubscribe = subscribe;
      return _ref = {
        /**
         * The minimal observable subscription method.
         * @param {Object} observer Any object that can be used as an observer.
         * The observer object should have a `next` method.
         * @returns {subscription} An object with an `unsubscribe` method that can
         * be used to unsubscribe the observable from the store, and prevent further
         * emission of values from the observable.
         */
        subscribe: function subscribe(observer) {
          if (typeof observer !== 'object' || observer === null) {
            throw new Error(formatProdErrorMessage(11) );
          }

          function observeState() {
            if (observer.next) {
              observer.next(getState());
            }
          }

          observeState();
          var unsubscribe = outerSubscribe(observeState);
          return {
            unsubscribe: unsubscribe
          };
        }
      }, _ref[$$observable] = function () {
        return this;
      }, _ref;
    } // When a store is created, an "INIT" action is dispatched so that every
    // reducer returns their initial state. This effectively populates
    // the initial state tree.


    dispatch({
      type: ActionTypes.INIT
    });
    return _ref2 = {
      dispatch: dispatch,
      subscribe: subscribe,
      getState: getState,
      replaceReducer: replaceReducer
    }, _ref2[$$observable] = observable, _ref2;
  }

  function assertReducerShape(reducers) {
    Object.keys(reducers).forEach(function (key) {
      var reducer = reducers[key];
      var initialState = reducer(undefined, {
        type: ActionTypes.INIT
      });

      if (typeof initialState === 'undefined') {
        throw new Error(formatProdErrorMessage(12) );
      }

      if (typeof reducer(undefined, {
        type: ActionTypes.PROBE_UNKNOWN_ACTION()
      }) === 'undefined') {
        throw new Error(formatProdErrorMessage(13) );
      }
    });
  }
  /**
   * Turns an object whose values are different reducer functions, into a single
   * reducer function. It will call every child reducer, and gather their results
   * into a single state object, whose keys correspond to the keys of the passed
   * reducer functions.
   *
   * @param {Object} reducers An object whose values correspond to different
   * reducer functions that need to be combined into one. One handy way to obtain
   * it is to use ES6 `import * as reducers` syntax. The reducers may never return
   * undefined for any action. Instead, they should return their initial state
   * if the state passed to them was undefined, and the current state for any
   * unrecognized action.
   *
   * @returns {Function} A reducer function that invokes every reducer inside the
   * passed object, and builds a state object with the same shape.
   */


  function combineReducers(reducers) {
    var reducerKeys = Object.keys(reducers);
    var finalReducers = {};

    for (var i = 0; i < reducerKeys.length; i++) {
      var key = reducerKeys[i];

      if (typeof reducers[key] === 'function') {
        finalReducers[key] = reducers[key];
      }
    }

    var finalReducerKeys = Object.keys(finalReducers); // This is used to make sure we don't warn about the same

    var shapeAssertionError;

    try {
      assertReducerShape(finalReducers);
    } catch (e) {
      shapeAssertionError = e;
    }

    return function combination(state, action) {
      if (state === void 0) {
        state = {};
      }

      if (shapeAssertionError) {
        throw shapeAssertionError;
      }

      var hasChanged = false;
      var nextState = {};

      for (var _i = 0; _i < finalReducerKeys.length; _i++) {
        var _key = finalReducerKeys[_i];
        var reducer = finalReducers[_key];
        var previousStateForKey = state[_key];
        var nextStateForKey = reducer(previousStateForKey, action);

        if (typeof nextStateForKey === 'undefined') {
          action && action.type;
          throw new Error(formatProdErrorMessage(14) );
        }

        nextState[_key] = nextStateForKey;
        hasChanged = hasChanged || nextStateForKey !== previousStateForKey;
      }

      hasChanged = hasChanged || finalReducerKeys.length !== Object.keys(state).length;
      return hasChanged ? nextState : state;
    };
  }

  /**
   * Composes single-argument functions from right to left. The rightmost
   * function can take multiple arguments as it provides the signature for
   * the resulting composite function.
   *
   * @param {...Function} funcs The functions to compose.
   * @returns {Function} A function obtained by composing the argument functions
   * from right to left. For example, compose(f, g, h) is identical to doing
   * (...args) => f(g(h(...args))).
   */
  function compose() {
    for (var _len = arguments.length, funcs = new Array(_len), _key = 0; _key < _len; _key++) {
      funcs[_key] = arguments[_key];
    }

    if (funcs.length === 0) {
      return function (arg) {
        return arg;
      };
    }

    if (funcs.length === 1) {
      return funcs[0];
    }

    return funcs.reduce(function (a, b) {
      return function () {
        return a(b.apply(void 0, arguments));
      };
    });
  }

  /**
   * Creates a store enhancer that applies middleware to the dispatch method
   * of the Redux store. This is handy for a variety of tasks, such as expressing
   * asynchronous actions in a concise manner, or logging every action payload.
   *
   * See `redux-thunk` package as an example of the Redux middleware.
   *
   * Because middleware is potentially asynchronous, this should be the first
   * store enhancer in the composition chain.
   *
   * Note that each middleware will be given the `dispatch` and `getState` functions
   * as named arguments.
   *
   * @param {...Function} middlewares The middleware chain to be applied.
   * @returns {Function} A store enhancer applying the middleware.
   */

  function applyMiddleware() {
    for (var _len = arguments.length, middlewares = new Array(_len), _key = 0; _key < _len; _key++) {
      middlewares[_key] = arguments[_key];
    }

    return function (createStore) {
      return function () {
        var store = createStore.apply(void 0, arguments);

        var _dispatch = function dispatch() {
          throw new Error(formatProdErrorMessage(15) );
        };

        var middlewareAPI = {
          getState: store.getState,
          dispatch: function dispatch() {
            return _dispatch.apply(void 0, arguments);
          }
        };
        var chain = middlewares.map(function (middleware) {
          return middleware(middlewareAPI);
        });
        _dispatch = compose.apply(void 0, chain)(store.dispatch);
        return _objectSpread2(_objectSpread2({}, store), {}, {
          dispatch: _dispatch
        });
      };
    };
  }

  /** A function that accepts a potential "extra argument" value to be injected later,
   * and returns an instance of the thunk middleware that uses that value
   */
  function createThunkMiddleware(extraArgument) {
    // Standard Redux middleware definition pattern:
    // See: https://redux.js.org/tutorials/fundamentals/part-4-store#writing-custom-middleware
    var middleware = function middleware(_ref) {
      var dispatch = _ref.dispatch,
          getState = _ref.getState;
      return function (next) {
        return function (action) {
          // The thunk middleware looks for any functions that were passed to `store.dispatch`.
          // If this "action" is really a function, call it and return the result.
          if (typeof action === 'function') {
            // Inject the store's `dispatch` and `getState` methods, as well as any "extra arg"
            return action(dispatch, getState, extraArgument);
          } // Otherwise, pass the action down the middleware chain as usual


          return next(action);
        };
      };
    };

    return middleware;
  }

  var thunk = createThunkMiddleware(); // Attach the factory function so users can create a customized version
  // with whatever "extra arg" they want to inject into their thunks

  thunk.withExtraArgument = createThunkMiddleware;
  var thunkMiddleware = thunk;

  var __extends = (globalThis && globalThis.__extends) || (function () {
      var extendStatics = function (d, b) {
          extendStatics = Object.setPrototypeOf ||
              ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
              function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
          return extendStatics(d, b);
      };
      return function (d, b) {
          if (typeof b !== "function" && b !== null)
              throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
          extendStatics(d, b);
          function __() { this.constructor = d; }
          d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
      };
  })();
  var __generator = (globalThis && globalThis.__generator) || function (thisArg, body) {
      var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
      return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
      function verb(n) { return function (v) { return step([n, v]); }; }
      function step(op) {
          if (f) throw new TypeError("Generator is already executing.");
          while (_) try {
              if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
              if (y = 0, t) op = [op[0] & 2, t.value];
              switch (op[0]) {
                  case 0: case 1: t = op; break;
                  case 4: _.label++; return { value: op[1], done: false };
                  case 5: _.label++; y = op[1]; op = [0]; continue;
                  case 7: op = _.ops.pop(); _.trys.pop(); continue;
                  default:
                      if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                      if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                      if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                      if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                      if (t[2]) _.ops.pop();
                      _.trys.pop(); continue;
              }
              op = body.call(thisArg, _);
          } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
          if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
      }
  };
  var __spreadArray = (globalThis && globalThis.__spreadArray) || function (to, from) {
      for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
          to[j] = from[i];
      return to;
  };
  var __defProp = Object.defineProperty;
  var __defProps = Object.defineProperties;
  var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
  var __getOwnPropSymbols = Object.getOwnPropertySymbols;
  var __hasOwnProp = Object.prototype.hasOwnProperty;
  var __propIsEnum = Object.prototype.propertyIsEnumerable;
  var __defNormalProp = function (obj, key, value) { return key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value: value }) : obj[key] = value; };
  var __spreadValues = function (a, b) {
      for (var prop in b || (b = {}))
          if (__hasOwnProp.call(b, prop))
              __defNormalProp(a, prop, b[prop]);
      if (__getOwnPropSymbols)
          for (var _i = 0, _c = __getOwnPropSymbols(b); _i < _c.length; _i++) {
              var prop = _c[_i];
              if (__propIsEnum.call(b, prop))
                  __defNormalProp(a, prop, b[prop]);
          }
      return a;
  };
  var __spreadProps = function (a, b) { return __defProps(a, __getOwnPropDescs(b)); };
  var __async = function (__this, __arguments, generator) {
      return new Promise(function (resolve, reject) {
          var fulfilled = function (value) {
              try {
                  step(generator.next(value));
              }
              catch (e) {
                  reject(e);
              }
          };
          var rejected = function (value) {
              try {
                  step(generator.throw(value));
              }
              catch (e) {
                  reject(e);
              }
          };
          var step = function (x) { return x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected); };
          step((generator = generator.apply(__this, __arguments)).next());
      });
  };
  var composeWithDevTools = typeof window !== "undefined" && window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__ ? window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__ : function () {
      if (arguments.length === 0)
          return void 0;
      if (typeof arguments[0] === "object")
          return compose;
      return compose.apply(null, arguments);
  };
  // src/isPlainObject.ts
  function isPlainObject(value) {
      if (typeof value !== "object" || value === null)
          return false;
      var proto = Object.getPrototypeOf(value);
      if (proto === null)
          return true;
      var baseProto = proto;
      while (Object.getPrototypeOf(baseProto) !== null) {
          baseProto = Object.getPrototypeOf(baseProto);
      }
      return proto === baseProto;
  }
  var MiddlewareArray = /** @class */ (function (_super) {
      __extends(MiddlewareArray, _super);
      function MiddlewareArray() {
          var args = [];
          for (var _i = 0; _i < arguments.length; _i++) {
              args[_i] = arguments[_i];
          }
          var _this = _super.apply(this, args) || this;
          Object.setPrototypeOf(_this, MiddlewareArray.prototype);
          return _this;
      }
      Object.defineProperty(MiddlewareArray, Symbol.species, {
          get: function () {
              return MiddlewareArray;
          },
          enumerable: false,
          configurable: true
      });
      MiddlewareArray.prototype.concat = function () {
          var arr = [];
          for (var _i = 0; _i < arguments.length; _i++) {
              arr[_i] = arguments[_i];
          }
          return _super.prototype.concat.apply(this, arr);
      };
      MiddlewareArray.prototype.prepend = function () {
          var arr = [];
          for (var _i = 0; _i < arguments.length; _i++) {
              arr[_i] = arguments[_i];
          }
          if (arr.length === 1 && Array.isArray(arr[0])) {
              return new (MiddlewareArray.bind.apply(MiddlewareArray, __spreadArray([void 0], arr[0].concat(this))))();
          }
          return new (MiddlewareArray.bind.apply(MiddlewareArray, __spreadArray([void 0], arr.concat(this))))();
      };
      return MiddlewareArray;
  }(Array));
  // src/getDefaultMiddleware.ts
  function isBoolean(x) {
      return typeof x === "boolean";
  }
  function curryGetDefaultMiddleware() {
      return function curriedGetDefaultMiddleware(options) {
          return getDefaultMiddleware(options);
      };
  }
  function getDefaultMiddleware(options) {
      if (options === void 0) { options = {}; }
      var _c = options.thunk, thunk = _c === void 0 ? true : _c; options.immutableCheck; options.serializableCheck;
      var middlewareArray = new MiddlewareArray();
      if (thunk) {
          if (isBoolean(thunk)) {
              middlewareArray.push(thunkMiddleware);
          }
          else {
              middlewareArray.push(thunkMiddleware.withExtraArgument(thunk.extraArgument));
          }
      }
      return middlewareArray;
  }
  // src/configureStore.ts
  var IS_PRODUCTION = "production" === "production";
  function configureStore(options) {
      var curriedGetDefaultMiddleware = curryGetDefaultMiddleware();
      var _c = options || {}, _d = _c.reducer, reducer = _d === void 0 ? void 0 : _d, _e = _c.middleware, middleware = _e === void 0 ? curriedGetDefaultMiddleware() : _e, _f = _c.devTools, devTools = _f === void 0 ? true : _f, _g = _c.preloadedState, preloadedState = _g === void 0 ? void 0 : _g, _h = _c.enhancers, enhancers = _h === void 0 ? void 0 : _h;
      var rootReducer;
      if (typeof reducer === "function") {
          rootReducer = reducer;
      }
      else if (isPlainObject(reducer)) {
          rootReducer = combineReducers(reducer);
      }
      else {
          throw new Error('"reducer" is a required argument, and must be a function or an object of functions that can be passed to combineReducers');
      }
      var finalMiddleware = middleware;
      if (typeof finalMiddleware === "function") {
          finalMiddleware = finalMiddleware(curriedGetDefaultMiddleware);
      }
      var middlewareEnhancer = applyMiddleware.apply(void 0, finalMiddleware);
      var finalCompose = compose;
      if (devTools) {
          finalCompose = composeWithDevTools(__spreadValues({
              trace: !IS_PRODUCTION
          }, typeof devTools === "object" && devTools));
      }
      var storeEnhancers = [middlewareEnhancer];
      if (Array.isArray(enhancers)) {
          storeEnhancers = __spreadArray([middlewareEnhancer], enhancers);
      }
      else if (typeof enhancers === "function") {
          storeEnhancers = enhancers(storeEnhancers);
      }
      var composedEnhancer = finalCompose.apply(void 0, storeEnhancers);
      return createStore(rootReducer, preloadedState, composedEnhancer);
  }
  // src/createAction.ts
  function createAction(type, prepareAction) {
      function actionCreator() {
          var args = [];
          for (var _i = 0; _i < arguments.length; _i++) {
              args[_i] = arguments[_i];
          }
          if (prepareAction) {
              var prepared = prepareAction.apply(void 0, args);
              if (!prepared) {
                  throw new Error("prepareAction did not return an object");
              }
              return __spreadValues(__spreadValues({
                  type: type,
                  payload: prepared.payload
              }, "meta" in prepared && { meta: prepared.meta }), "error" in prepared && { error: prepared.error });
          }
          return { type: type, payload: args[0] };
      }
      actionCreator.toString = function () { return "" + type; };
      actionCreator.type = type;
      actionCreator.match = function (action) { return action.type === type; };
      return actionCreator;
  }
  // src/nanoid.ts
  var urlAlphabet = "ModuleSymbhasOwnPr-0123456789ABCDEFGHNRVfgctiUvz_KqYTJkLxpZXIjQW";
  var nanoid = function (size) {
      if (size === void 0) { size = 21; }
      var id = "";
      var i = size;
      while (i--) {
          id += urlAlphabet[Math.random() * 64 | 0];
      }
      return id;
  };
  // src/createAsyncThunk.ts
  var commonProperties = [
      "name",
      "message",
      "stack",
      "code"
  ];
  var RejectWithValue = /** @class */ (function () {
      function RejectWithValue(payload, meta) {
          this.payload = payload;
          this.meta = meta;
      }
      return RejectWithValue;
  }());
  var FulfillWithMeta = /** @class */ (function () {
      function FulfillWithMeta(payload, meta) {
          this.payload = payload;
          this.meta = meta;
      }
      return FulfillWithMeta;
  }());
  var miniSerializeError = function (value) {
      if (typeof value === "object" && value !== null) {
          var simpleError = {};
          for (var _i = 0, commonProperties_1 = commonProperties; _i < commonProperties_1.length; _i++) {
              var property = commonProperties_1[_i];
              if (typeof value[property] === "string") {
                  simpleError[property] = value[property];
              }
          }
          return simpleError;
      }
      return { message: String(value) };
  };
  ((function () {
      function createAsyncThunk2(typePrefix, payloadCreator, options) {
          var fulfilled = createAction(typePrefix + "/fulfilled", function (payload, requestId, arg, meta) { return ({
              payload: payload,
              meta: __spreadProps(__spreadValues({}, meta || {}), {
                  arg: arg,
                  requestId: requestId,
                  requestStatus: "fulfilled"
              })
          }); });
          var pending = createAction(typePrefix + "/pending", function (requestId, arg, meta) { return ({
              payload: void 0,
              meta: __spreadProps(__spreadValues({}, meta || {}), {
                  arg: arg,
                  requestId: requestId,
                  requestStatus: "pending"
              })
          }); });
          var rejected = createAction(typePrefix + "/rejected", function (error, requestId, arg, payload, meta) { return ({
              payload: payload,
              error: (options && options.serializeError || miniSerializeError)(error || "Rejected"),
              meta: __spreadProps(__spreadValues({}, meta || {}), {
                  arg: arg,
                  requestId: requestId,
                  rejectedWithValue: !!payload,
                  requestStatus: "rejected",
                  aborted: (error == null ? void 0 : error.name) === "AbortError",
                  condition: (error == null ? void 0 : error.name) === "ConditionError"
              })
          }); });
          var AC = typeof AbortController !== "undefined" ? AbortController : /** @class */ (function () {
              function class_1() {
                  this.signal = {
                      aborted: false,
                      addEventListener: function () {
                      },
                      dispatchEvent: function () {
                          return false;
                      },
                      onabort: function () {
                      },
                      removeEventListener: function () {
                      },
                      reason: void 0,
                      throwIfAborted: function () {
                      }
                  };
              }
              class_1.prototype.abort = function () {
              };
              return class_1;
          }());
          function actionCreator(arg) {
              return function (dispatch, getState, extra) {
                  var requestId = (options == null ? void 0 : options.idGenerator) ? options.idGenerator(arg) : nanoid();
                  var abortController = new AC();
                  var abortReason;
                  var abortedPromise = new Promise(function (_, reject) { return abortController.signal.addEventListener("abort", function () { return reject({ name: "AbortError", message: abortReason || "Aborted" }); }); });
                  var started = false;
                  function abort(reason) {
                      if (started) {
                          abortReason = reason;
                          abortController.abort();
                      }
                  }
                  var promise2 = function () {
                      return __async(this, null, function () {
                          var _a, _b, finalAction, conditionResult, err_1, skipDispatch;
                          return __generator(this, function (_c) {
                              switch (_c.label) {
                                  case 0:
                                      _c.trys.push([0, 4, , 5]);
                                      conditionResult = (_a = options == null ? void 0 : options.condition) == null ? void 0 : _a.call(options, arg, { getState: getState, extra: extra });
                                      if (!isThenable(conditionResult)) return [3 /*break*/, 2];
                                      return [4 /*yield*/, conditionResult];
                                  case 1:
                                      conditionResult = _c.sent();
                                      _c.label = 2;
                                  case 2:
                                      if (conditionResult === false) {
                                          throw {
                                              name: "ConditionError",
                                              message: "Aborted due to condition callback returning false."
                                          };
                                      }
                                      started = true;
                                      dispatch(pending(requestId, arg, (_b = options == null ? void 0 : options.getPendingMeta) == null ? void 0 : _b.call(options, { requestId: requestId, arg: arg }, { getState: getState, extra: extra })));
                                      return [4 /*yield*/, Promise.race([
                                              abortedPromise,
                                              Promise.resolve(payloadCreator(arg, {
                                                  dispatch: dispatch,
                                                  getState: getState,
                                                  extra: extra,
                                                  requestId: requestId,
                                                  signal: abortController.signal,
                                                  abort: abort,
                                                  rejectWithValue: function (value, meta) {
                                                      return new RejectWithValue(value, meta);
                                                  },
                                                  fulfillWithValue: function (value, meta) {
                                                      return new FulfillWithMeta(value, meta);
                                                  }
                                              })).then(function (result) {
                                                  if (result instanceof RejectWithValue) {
                                                      throw result;
                                                  }
                                                  if (result instanceof FulfillWithMeta) {
                                                      return fulfilled(result.payload, requestId, arg, result.meta);
                                                  }
                                                  return fulfilled(result, requestId, arg);
                                              })
                                          ])];
                                  case 3:
                                      finalAction = _c.sent();
                                      return [3 /*break*/, 5];
                                  case 4:
                                      err_1 = _c.sent();
                                      finalAction = err_1 instanceof RejectWithValue ? rejected(null, requestId, arg, err_1.payload, err_1.meta) : rejected(err_1, requestId, arg);
                                      return [3 /*break*/, 5];
                                  case 5:
                                      skipDispatch = options && !options.dispatchConditionRejection && rejected.match(finalAction) && finalAction.meta.condition;
                                      if (!skipDispatch) {
                                          dispatch(finalAction);
                                      }
                                      return [2 /*return*/, finalAction];
                              }
                          });
                      });
                  }();
                  return Object.assign(promise2, {
                      abort: abort,
                      requestId: requestId,
                      arg: arg,
                      unwrap: function () {
                          return promise2.then(unwrapResult);
                      }
                  });
              };
          }
          return Object.assign(actionCreator, {
              pending: pending,
              rejected: rejected,
              fulfilled: fulfilled,
              typePrefix: typePrefix
          });
      }
      createAsyncThunk2.withTypes = createAsyncThunk2;
      return createAsyncThunk2;
  }))();
  function unwrapResult(action) {
      if (action.meta && action.meta.rejectedWithValue) {
          throw action.payload;
      }
      if (action.error) {
          throw action.error;
      }
      return action.payload;
  }
  function isThenable(value) {
      return value !== null && typeof value === "object" && typeof value.then === "function";
  }
  var alm = "listenerMiddleware";
  createAction(alm + "/add");
  createAction(alm + "/removeAll");
  createAction(alm + "/remove");
  var promise;
  typeof queueMicrotask === "function" ? queueMicrotask.bind(typeof window !== "undefined" ? window : global) : function (cb) { return (promise || (promise = Promise.resolve())).then(cb).catch(function (err) { return setTimeout(function () {
      throw err;
  }, 0); }); };
  // src/index.ts
  immer_esm.N();

  let init = {
    counter: 0
  };
  const reduce = immer_esm.produce((draft, action) => {
    switch (action.type) {
      case "INCREMENT":
        draft.counter++;
        break;
      case "DECREMENT":
        draft.counter--;
        break;
    }
  });
  const reducer = (state = init, action) => {
    const next = reduce(state, action);
    return next;
  };
  const store = configureStore({
    reducer,
    preloadedState: init
  });
  const listeners = new Map();
  addEventListener("message", ({
    data
  }) => {
    console.log(data);
    switch (data.type) {
      case "dispatch":
        store.dispatch(data.action);
        break;
      case "subscribe":
        listeners.set(data.uuid, data.selector);
        runSelector(data.selector, data.uuid);
        break;
      case "unsubscribe":
        listeners.delete(data.uuid);
        break;
    }
  });
  store.subscribe(() => {
    listeners.forEach(runSelector);
  });
  function runSelector(value, key) {
    let returnValue;
    switch (value.selector) {
      case "one":
        returnValue = one();
        break;
      case "two":
        returnValue = two(value.params);
        break;
    }
    if (returnValue !== undefined) {
      postMessage({
        uuid: key,
        value: returnValue
      });
    }
  }
  function one() {
    return store.getState().counter;
  }
  function two(params) {
    return `${params.hello} ${one() / 2}`;
  }

}));
//# sourceMappingURL=basic-worker-dc2c9760.js.map
