/**
 * Copyright 2018 Google Inc. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *     http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// If the loader is already loaded, just stop.
if (!self.define) {
  const singleRequire = name => {
    if (name !== 'require') {
      name = name + '.js';
    }
    let promise = Promise.resolve();
    if (!registry[name]) {
      
        promise = new Promise(async resolve => {
          if ("document" in self) {
            const script = document.createElement("script");
            script.src = name;
            document.head.appendChild(script);
            script.onload = resolve;
          } else {
            importScripts(name);
            resolve();
          }
        });
      
    }
    return promise.then(() => {
      if (!registry[name]) {
        throw new Error(`Module ${name} didn’t register its module`);
      }
      return registry[name];
    });
  };

  const require = (names, resolve) => {
    Promise.all(names.map(singleRequire))
      .then(modules => resolve(modules.length === 1 ? modules[0] : modules));
  };
  
  const registry = {
    require: Promise.resolve(require)
  };

  self.define = (moduleName, depsNames, factory) => {
    if (registry[moduleName]) {
      // Module is already loading or loaded.
      return;
    }
    registry[moduleName] = Promise.resolve().then(() => {
      let exports = {};
      const module = {
        uri: location.origin + moduleName.slice(1)
      };
      return Promise.all(
        depsNames.map(depName => {
          switch(depName) {
            case "exports":
              return exports;
            case "module":
              return module;
            default:
              return singleRequire(depName);
          }
        })
      ).then(deps => {
        const facValue = factory(...deps);
        if(!exports.default) {
          exports.default = facValue;
        }
        return exports;
      });
    });
  };
}
define("./worker-56d44cf9.js",['exports', './comlink-9c0458b2'], function (exports, comlink) { 'use strict';

  /**
   * Adapted from React: https://github.com/facebook/react/blob/master/packages/shared/formatProdErrorMessage.js
   *
   * Do not require this module directly! Use normal throw error calls. These messages will be replaced with error codes
   * during build.
   * @param {number} code
   */
  function formatProdErrorMessage(code) {
    return "Minified Redux error #" + code + "; visit https://redux.js.org/Errors?code=" + code + " for the full message or " + 'use the non-minified dev environment for full errors. ';
  }

  // Inlined version of the `symbol-observable` polyfill
  var $$observable = (function () {
    return typeof Symbol === 'function' && Symbol.observable || '@@observable';
  })();

  /**
   * These are private action types reserved by Redux.
   * For any unknown actions, you must return the current state.
   * If the current state is undefined, you must return the initial state.
   * Do not reference these action types directly in your code.
   */
  var randomString = function randomString() {
    return Math.random().toString(36).substring(7).split('').join('.');
  };

  var ActionTypes = {
    INIT: "@@redux/INIT" + randomString(),
    REPLACE: "@@redux/REPLACE" + randomString(),
    PROBE_UNKNOWN_ACTION: function PROBE_UNKNOWN_ACTION() {
      return "@@redux/PROBE_UNKNOWN_ACTION" + randomString();
    }
  };

  /**
   * @param {any} obj The object to inspect.
   * @returns {boolean} True if the argument appears to be a plain object.
   */
  function isPlainObject(obj) {
    if (typeof obj !== 'object' || obj === null) return false;
    var proto = obj;

    while (Object.getPrototypeOf(proto) !== null) {
      proto = Object.getPrototypeOf(proto);
    }

    return Object.getPrototypeOf(obj) === proto;
  }

  /**
   * Creates a Redux store that holds the state tree.
   * The only way to change the data in the store is to call `dispatch()` on it.
   *
   * There should only be a single store in your app. To specify how different
   * parts of the state tree respond to actions, you may combine several reducers
   * into a single reducer function by using `combineReducers`.
   *
   * @param {Function} reducer A function that returns the next state tree, given
   * the current state tree and the action to handle.
   *
   * @param {any} [preloadedState] The initial state. You may optionally specify it
   * to hydrate the state from the server in universal apps, or to restore a
   * previously serialized user session.
   * If you use `combineReducers` to produce the root reducer function, this must be
   * an object with the same shape as `combineReducers` keys.
   *
   * @param {Function} [enhancer] The store enhancer. You may optionally specify it
   * to enhance the store with third-party capabilities such as middleware,
   * time travel, persistence, etc. The only store enhancer that ships with Redux
   * is `applyMiddleware()`.
   *
   * @returns {Store} A Redux store that lets you read the state, dispatch actions
   * and subscribe to changes.
   */

  function createStore(reducer, preloadedState, enhancer) {
    var _ref2;

    if (typeof preloadedState === 'function' && typeof enhancer === 'function' || typeof enhancer === 'function' && typeof arguments[3] === 'function') {
      throw new Error( formatProdErrorMessage(0) );
    }

    if (typeof preloadedState === 'function' && typeof enhancer === 'undefined') {
      enhancer = preloadedState;
      preloadedState = undefined;
    }

    if (typeof enhancer !== 'undefined') {
      if (typeof enhancer !== 'function') {
        throw new Error( formatProdErrorMessage(1) );
      }

      return enhancer(createStore)(reducer, preloadedState);
    }

    if (typeof reducer !== 'function') {
      throw new Error( formatProdErrorMessage(2) );
    }

    var currentReducer = reducer;
    var currentState = preloadedState;
    var currentListeners = [];
    var nextListeners = currentListeners;
    var isDispatching = false;
    /**
     * This makes a shallow copy of currentListeners so we can use
     * nextListeners as a temporary list while dispatching.
     *
     * This prevents any bugs around consumers calling
     * subscribe/unsubscribe in the middle of a dispatch.
     */

    function ensureCanMutateNextListeners() {
      if (nextListeners === currentListeners) {
        nextListeners = currentListeners.slice();
      }
    }
    /**
     * Reads the state tree managed by the store.
     *
     * @returns {any} The current state tree of your application.
     */


    function getState() {
      if (isDispatching) {
        throw new Error( formatProdErrorMessage(3) );
      }

      return currentState;
    }
    /**
     * Adds a change listener. It will be called any time an action is dispatched,
     * and some part of the state tree may potentially have changed. You may then
     * call `getState()` to read the current state tree inside the callback.
     *
     * You may call `dispatch()` from a change listener, with the following
     * caveats:
     *
     * 1. The subscriptions are snapshotted just before every `dispatch()` call.
     * If you subscribe or unsubscribe while the listeners are being invoked, this
     * will not have any effect on the `dispatch()` that is currently in progress.
     * However, the next `dispatch()` call, whether nested or not, will use a more
     * recent snapshot of the subscription list.
     *
     * 2. The listener should not expect to see all state changes, as the state
     * might have been updated multiple times during a nested `dispatch()` before
     * the listener is called. It is, however, guaranteed that all subscribers
     * registered before the `dispatch()` started will be called with the latest
     * state by the time it exits.
     *
     * @param {Function} listener A callback to be invoked on every dispatch.
     * @returns {Function} A function to remove this change listener.
     */


    function subscribe(listener) {
      if (typeof listener !== 'function') {
        throw new Error( formatProdErrorMessage(4) );
      }

      if (isDispatching) {
        throw new Error( formatProdErrorMessage(5) );
      }

      var isSubscribed = true;
      ensureCanMutateNextListeners();
      nextListeners.push(listener);
      return function unsubscribe() {
        if (!isSubscribed) {
          return;
        }

        if (isDispatching) {
          throw new Error( formatProdErrorMessage(6) );
        }

        isSubscribed = false;
        ensureCanMutateNextListeners();
        var index = nextListeners.indexOf(listener);
        nextListeners.splice(index, 1);
        currentListeners = null;
      };
    }
    /**
     * Dispatches an action. It is the only way to trigger a state change.
     *
     * The `reducer` function, used to create the store, will be called with the
     * current state tree and the given `action`. Its return value will
     * be considered the **next** state of the tree, and the change listeners
     * will be notified.
     *
     * The base implementation only supports plain object actions. If you want to
     * dispatch a Promise, an Observable, a thunk, or something else, you need to
     * wrap your store creating function into the corresponding middleware. For
     * example, see the documentation for the `redux-thunk` package. Even the
     * middleware will eventually dispatch plain object actions using this method.
     *
     * @param {Object} action A plain object representing “what changed”. It is
     * a good idea to keep actions serializable so you can record and replay user
     * sessions, or use the time travelling `redux-devtools`. An action must have
     * a `type` property which may not be `undefined`. It is a good idea to use
     * string constants for action types.
     *
     * @returns {Object} For convenience, the same action object you dispatched.
     *
     * Note that, if you use a custom middleware, it may wrap `dispatch()` to
     * return something else (for example, a Promise you can await).
     */


    function dispatch(action) {
      if (!isPlainObject(action)) {
        throw new Error( formatProdErrorMessage(7) );
      }

      if (typeof action.type === 'undefined') {
        throw new Error( formatProdErrorMessage(8) );
      }

      if (isDispatching) {
        throw new Error( formatProdErrorMessage(9) );
      }

      try {
        isDispatching = true;
        currentState = currentReducer(currentState, action);
      } finally {
        isDispatching = false;
      }

      var listeners = currentListeners = nextListeners;

      for (var i = 0; i < listeners.length; i++) {
        var listener = listeners[i];
        listener();
      }

      return action;
    }
    /**
     * Replaces the reducer currently used by the store to calculate the state.
     *
     * You might need this if your app implements code splitting and you want to
     * load some of the reducers dynamically. You might also need this if you
     * implement a hot reloading mechanism for Redux.
     *
     * @param {Function} nextReducer The reducer for the store to use instead.
     * @returns {void}
     */


    function replaceReducer(nextReducer) {
      if (typeof nextReducer !== 'function') {
        throw new Error( formatProdErrorMessage(10) );
      }

      currentReducer = nextReducer; // This action has a similiar effect to ActionTypes.INIT.
      // Any reducers that existed in both the new and old rootReducer
      // will receive the previous state. This effectively populates
      // the new state tree with any relevant data from the old one.

      dispatch({
        type: ActionTypes.REPLACE
      });
    }
    /**
     * Interoperability point for observable/reactive libraries.
     * @returns {observable} A minimal observable of state changes.
     * For more information, see the observable proposal:
     * https://github.com/tc39/proposal-observable
     */


    function observable() {
      var _ref;

      var outerSubscribe = subscribe;
      return _ref = {
        /**
         * The minimal observable subscription method.
         * @param {Object} observer Any object that can be used as an observer.
         * The observer object should have a `next` method.
         * @returns {subscription} An object with an `unsubscribe` method that can
         * be used to unsubscribe the observable from the store, and prevent further
         * emission of values from the observable.
         */
        subscribe: function subscribe(observer) {
          if (typeof observer !== 'object' || observer === null) {
            throw new Error( formatProdErrorMessage(11) );
          }

          function observeState() {
            if (observer.next) {
              observer.next(getState());
            }
          }

          observeState();
          var unsubscribe = outerSubscribe(observeState);
          return {
            unsubscribe: unsubscribe
          };
        }
      }, _ref[$$observable] = function () {
        return this;
      }, _ref;
    } // When a store is created, an "INIT" action is dispatched so that every
    // reducer returns their initial state. This effectively populates
    // the initial state tree.


    dispatch({
      type: ActionTypes.INIT
    });
    return _ref2 = {
      dispatch: dispatch,
      subscribe: subscribe,
      getState: getState,
      replaceReducer: replaceReducer
    }, _ref2[$$observable] = observable, _ref2;
  }

  function e(e){return "symbol"==typeof e||isNaN(e)}function t(e){var t=0;for(var{size:r}of Object.values(e))t+=r;return t}function r(t,r,n){var{byteOffset:i=0,length:f=0}=void 0===n?{}:n,s=new DataView(t,i),a=0;for(var[o,b]of(r=Object.assign({},r),Object.entries(r)))r[o]=Object.assign({},b,{offset:a}),a+=b.size;return f||(f=Math.floor((t.byteLength-i)/a)),new Proxy(new Array(f),{has:(t,r)=>e(r)?"buffer"===r||r in t:r<f,get(n,i,f){if("buffer"===i)return t;if(e(i)){var o=n[i];return "function"==typeof o&&(o=o.bind(f)),o}var b=parseInt(i),u=b*a;if(!(b>=n.length)){if(!n[b]){n[b]={};var c=function(e,t){if(!("get"in t))return "continue";Object.defineProperty(n[b],e,{enumerable:!0,get:()=>t.get(s,u+t.offset),set:e=>t.set(s,u+t.offset,e)});};for(var[g,l]of Object.entries(r))c(g,l);Object.freeze(n[b]);}return n[b]}}})}function n(e,t,n){var{byteOffset:i=0}=void 0===n?{}:n;return r(e,t,{byteOffset:i})[0]}"object"!=typeof globalThis&&(Object.prototype.__defineGetter__("__magic__",function(){return this}),__magic__.globalThis=__magic__,delete Object.prototype.__magic__),["Uint16","Uint32","Int16","Int32","Float32","Float64","BigInt64","BigUint64"].forEach(e=>{n[e]=function(t){var{endianess:r="big"}=void 0===t?{}:t;if("big"!==r&&"little"!==r)throw Error("Endianness needs to be either 'big' or 'little'");var n="little"===r;return {size:globalThis[e+"Array"].BYTES_PER_ELEMENT,get:(t,r)=>t["get"+e](r,n),set:(t,r,i)=>t["set"+e](r,i,n)}};}),n.Uint8=()=>({size:1,get:(e,t)=>e.getUint8(t),set:(e,t,r)=>e.setUint8(t,r)}),n.Int8=()=>({size:1,get:(e,t)=>e.getInt8(t),set:(e,t,r)=>e.setInt8(t,r)}),n.ArrayBuffer=e=>({size:e,get:(t,r)=>t.buffer.subarray(r,r+e),set:(t,r,n)=>new Uint8Array(t.buffer.subarray(r,r+e)).set(new Uint8Array(n))}),n.NestedBufferBackedObject=e=>({size:t(e),get:(t,n)=>new r(t.buffer,e,{byteOffset:n,length:1})[0],set:(e,t,r)=>{throw Error("Can’t set an entire struct")}}),n.NestedArrayOfBufferBackedObjects=(e,n)=>({size:t(n)*e,get:(t,i)=>new r(t.buffer,n,{byteOffset:i,length:e}),set:(e,t,r)=>{throw Error("Can’t set an entire array")}}),n.UTF8String=e=>({size:e,get:(t,r)=>(new TextDecoder).decode(new Uint8Array(t.buffer,r,e)).replace(/\u0000+$/,""),set:(t,r,n)=>{var i=(new TextEncoder).encode(n),f=new Uint8Array(t.buffer,r,e);f.fill(0),f.set(i.subarray(0,e));}}),n.reserved=e=>({size:e});//# sourceMappingURL=buffer-backed-object.modern.js.map

  comlink.T();
  let init = {};
  let patches;
  let arrayBuffer;

  function uuidv4() {
    return ([1e7] + -1e3 + -4e3 + -8e3 + -1e11).replace(/[018]/g, c => (c ^ crypto.getRandomValues(new Uint8Array(1))[0] & 15 >> c / 4).toString(16));
  }

  const reduce = comlink.cn((draft, action) => {
    const key = uuidv4();

    switch (action.type) {
      case "INCREMENT":
        draft[key] = {
          value: `${key}-increment`
        };
        break;

      case "DECREMENT":
        draft[key] = {
          value: `${key}-decrement`
        };
        break;
    }
  });

  function byteSize(str) {
    return new Blob([str]).size;
  }

  function decode(dataView, byteOffset, maxBytes) {
    return new TextDecoder().decode(new Uint8Array(dataView.buffer, byteOffset, maxBytes)).replace(/\u0000+$/, "");
  }

  function create(dataView, byteOffset, value, maxBytes) {
    const encoding = new TextEncoder().encode(value);
    const target = new Uint8Array(dataView.buffer, byteOffset, maxBytes);
    target.fill(0);
    target.set(encoding.subarray(0, maxBytes));
  }

  const stringArrayBuffer = () => {
    let pathAsBytes = [];

    function get(dataView, byteOffset) {
      let offset = byteOffset;
      let values = [];

      for (let i = 0; i < pathAsBytes.length; i++) {
        const size = pathAsBytes[i];
        const value = decode(dataView, offset, size);
        values.push(value);
        offset += size;
      }

      return values;
    }

    function set(dataView, byteOffset, values) {
      let offset = byteOffset;
      pathAsBytes = values.map(byteSize);

      for (let i = 0; i < values.length; i++) {
        const size = pathAsBytes[i];
        create(dataView, offset, values[i], size);
        offset += size;
      }
    }

    return {
      size: 0,
      get,
      set
    };
  };

  const reducer = (state = init, action) => {
    const [next, nextPatches] = reduce(state, action);
    patches = nextPatches; // calculate the buffer size, op, and value

    const buffer = new ArrayBuffer(256);
    const dataView = new r(buffer, {
      op: n.UTF8String(64),
      path: stringArrayBuffer(),
      value: n.UTF8String(64)
    }); // dataView.push(...(patches as any));

    patches.forEach((patch, i) => {
      dataView[i] = patch;
    });
    arrayBuffer = buffer;
    console.log(JSON.stringify(dataView, null, 2));
    return next;
  }; // expose


  function getPatches() {
    return patches;
  }

  function getBuffer() {
    return arrayBuffer;
  } //expose general fetch handler in here
  //this way heavy parsing takes place in the worker


  const store = createStore(reducer);
  comlink.expose({
    getState: store.getState,
    dispatch: store.dispatch,
    subscribe: func => {
      store.subscribe(func);
    },
    getPatches,
    getBuffer
  });

  exports.stringArrayBuffer = stringArrayBuffer;

  Object.defineProperty(exports, '__esModule', { value: true });

});
//# sourceMappingURL=worker-56d44cf9.js.map
